==> 1.0.1%2B1.tar.gz: android/src/main/java/com/bradyid/brady_flutter_plugin/BradyFlutterPlugin.java <==
package com.bradyid.brady_flutter_plugin;

import android.Manifest;
import android.app.Activity;
import android.content.Context;
import android.content.pm.PackageManager;
import android.os.Build;

import androidx.annotation.NonNull;
import androidx.core.app.ActivityCompat;
import androidx.core.content.ContextCompat;

import com.bradysdk.api.printerdiscovery.DiscoveredPrinterInformation;
import com.bradysdk.api.printerdiscovery.PrinterDiscovery;
import com.bradysdk.api.printerdiscovery.PrinterDiscoveryListener;
import com.bradysdk.printengine.printinginterface.PrinterDiscoveryFactory;

import java.io.ByteArrayInputStream;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.Base64;
import java.util.List;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;

/** BradyFlutterPlugin */
public class BradyFlutterPlugin implements FlutterPlugin, MethodCallHandler, ActivityAware {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private MethodChannel channel;
  private Activity activity;
  private Context context;
  private BradySdkApi bradySdk;

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "brady_flutter_plugin");
    channel.setMethodCallHandler(this);
    context = flutterPluginBinding.getApplicationContext();
    bradySdk = new BradySdkApi(context);
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    if (call.method.equals("getPlatformVersion")) {
      result.success("Android " + android.os.Build.VERSION.RELEASE);
    } else if (call.method.equals("startPrinterDiscovery")) {
      bradySdk.startPrinterDiscovery();
    } else if (call.method.equals("getPrinters")) {
      result.success(bradySdk.getPrinters());
    } else if (call.method.equals("connectToPrinter")) {
      final String printer = call.argument("printerName");
      Boolean connected = bradySdk.connectToPrinter(printer);
      if (connected) {
        bradySdk.stopPrinterDiscovery();
      }
      result.success(connected);
    } else if (call.method.equals("getPrinterDetails")) {
      String printerDetails = bradySdk.getPrinterDetails();
      result.success(printerDetails);
    } else if (call.method.equals("getLastConnectedPrinterName")) {
      String printerName = bradySdk.getLastConnectedPrinterName();
      result.success(printerName);
    } else if (call.method.equals("setTemplate")) {
      final String base64 = call.argument("byteData");
      if (base64 != null) {
        if (android.os.Build.VERSION.SDK_INT >= android.os.Build.VERSION_CODES.O) {
          byte[] encoded = Base64.getDecoder().decode(base64);
          InputStream inputStream = new ByteArrayInputStream(encoded);
          bradySdk.setTemplate(inputStream);
        }
      }
    } else if (call.method.equals("setPlaceholderValue")) {
      final String placeholder = call.argument("placeholder");
      final String value = call.argument("value");
      bradySdk.setPlaceholderValue(placeholder, value);
    } else if (call.method.equals("print")) {
      Boolean printed = bradySdk.print();
      result.success(printed);
    } else if (call.method.equals("feed")) {
      Boolean fed = bradySdk.feed();
      result.success(fed);
    } else if (call.method.equals("cut")) {
      Boolean cut = bradySdk.cut();
      result.success(cut);
    } else if (call.method.equals("disconnect")) {
      Boolean disconnected = bradySdk.disconnect();
      result.success(disconnected);
    } else {
      result.notImplemented();
    }
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }

  @Override
  public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
    activity = binding.getActivity();
    if (ContextCompat.checkSelfPermission(context, Manifest.permission.BLUETOOTH_CONNECT) != PackageManager.PERMISSION_GRANTED ||
            ContextCompat.checkSelfPermission(context, Manifest.permission.BLUETOOTH_SCAN) != PackageManager.PERMISSION_GRANTED ||
            ContextCompat.checkSelfPermission(context, Manifest.permission.ACCESS_FINE_LOCATION) != PackageManager.PERMISSION_GRANTED ||
            ContextCompat.checkSelfPermission(context, Manifest.permission.BLUETOOTH) != PackageManager.PERMISSION_GRANTED) {
      if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.S) {
        ActivityCompat.requestPermissions(activity, new String[]{Manifest.permission.BLUETOOTH_CONNECT, Manifest.permission.BLUETOOTH_SCAN,
                Manifest.permission.ACCESS_FINE_LOCATION, Manifest.permission.BLUETOOTH}, 0);
      }
      else{
        ActivityCompat.requestPermissions(activity, new String[]{Manifest.permission.ACCESS_COARSE_LOCATION, Manifest.permission.ACCESS_FINE_LOCATION, Manifest.permission.BLUETOOTH}, 0);
      }
    }
  }

  @Override
  public void onDetachedFromActivityForConfigChanges() {

  }

  @Override
  public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding) {

  }

  @Override
  public void onDetachedFromActivity() {

  }
}

==> 1.0.3%2B1.tar.gz: android/src/main/java/com/bradyid/brady_flutter_plugin/BradyFlutterPlugin.java <==
package com.bradyid.brady_flutter_plugin;

import android.Manifest;
import android.app.Activity;
import android.content.Context;
import android.content.pm.PackageManager;
import android.os.Build;

import androidx.annotation.NonNull;
import androidx.core.app.ActivityCompat;
import androidx.core.content.ContextCompat;

import com.bradysdk.api.printerdiscovery.DiscoveredPrinterInformation;
import com.bradysdk.api.printerdiscovery.PrinterDiscovery;
import com.bradysdk.api.printerdiscovery.PrinterDiscoveryListener;
import com.bradysdk.printengine.printinginterface.PrinterDiscoveryFactory;

import java.io.ByteArrayInputStream;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.Base64;
import java.util.List;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;

/** BradyFlutterPlugin */
public class BradyFlutterPlugin implements FlutterPlugin, MethodCallHandler, ActivityAware {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private MethodChannel channel;
  private Activity activity;
  private Context context;
  private BradySdkApi bradySdk;

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "brady_flutter_plugin");
    channel.setMethodCallHandler(this);
    context = flutterPluginBinding.getApplicationContext();
    bradySdk = new BradySdkApi(context);
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    if (call.method.equals("startPrinterDiscovery")) {
      bradySdk.startPrinterDiscovery();
    } else if (call.method.equals("getPrinters")) {
      result.success(bradySdk.getPrinters());
    } else if (call.method.equals("connectToPrinter")) {
      final String printer = call.argument("printerName");
      Boolean connected = bradySdk.connectToPrinter(printer);
      result.success(connected);
    } else if (call.method.equals("getPrinterDetails")) {
      String printerDetails = bradySdk.getPrinterDetails();
      result.success(printerDetails);
    } else if (call.method.equals("getLastConnectedPrinterName")) {
      String printerName = bradySdk.getLastConnectedPrinterName();
      result.success(printerName);
    } else if (call.method.equals("setTemplate")) {
      final String base64 = call.argument("byteData");
      if (base64 != null) {
          bradySdk.setTemplate(base64);
      }
    } else if (call.method.equals("setPlaceholderValue")) {
      final String placeholder = call.argument("placeholder");
      final String value = call.argument("value");
      bradySdk.setPlaceholderValue(placeholder, value);
    } else if (call.method.equals("print")) {
      Boolean printed = bradySdk.print();
      result.success(printed);
    } else if (call.method.equals("feed")) {
      Boolean fed = bradySdk.feed();
      result.success(fed);
    } else if (call.method.equals("cut")) {
      Boolean cut = bradySdk.cut();
      result.success(cut);
    } else if (call.method.equals("disconnect")) {
      Boolean disconnected = bradySdk.disconnect();
      result.success(disconnected);
    } else {
      result.notImplemented();
    }
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }

  @Override
  public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
    activity = binding.getActivity();
    if (ContextCompat.checkSelfPermission(context, Manifest.permission.BLUETOOTH_CONNECT) != PackageManager.PERMISSION_GRANTED ||
            ContextCompat.checkSelfPermission(context, Manifest.permission.BLUETOOTH_SCAN) != PackageManager.PERMISSION_GRANTED ||
            ContextCompat.checkSelfPermission(context, Manifest.permission.ACCESS_FINE_LOCATION) != PackageManager.PERMISSION_GRANTED ||
            ContextCompat.checkSelfPermission(context, Manifest.permission.BLUETOOTH) != PackageManager.PERMISSION_GRANTED) {
      if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.S) {
        ActivityCompat.requestPermissions(activity, new String[]{Manifest.permission.BLUETOOTH_CONNECT, Manifest.permission.BLUETOOTH_SCAN,
                Manifest.permission.ACCESS_FINE_LOCATION, Manifest.permission.BLUETOOTH}, 0);
      }
      else{
        ActivityCompat.requestPermissions(activity, new String[]{Manifest.permission.ACCESS_COARSE_LOCATION, Manifest.permission.ACCESS_FINE_LOCATION, Manifest.permission.BLUETOOTH}, 0);
      }
    }
  }

  @Override
  public void onDetachedFromActivityForConfigChanges() {

  }

  @Override
  public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding) {

  }

  @Override
  public void onDetachedFromActivity() {

  }
}
